@@ -12,9 +12,12 @@ from .request import basic_request
 
 class Authorization():
 
-    def __init__(self, api_key, api_secret):
+    def __init__(self, api_key, api_secret, merchant, terminal, biller):
         self.api_key = api_key
         self.api_secret = api_secret
+        self.merchant = merchant
+        self.terminal = terminal
+        self.biller = biller
         self.API_ROOT = ENDPOINTS["API_ROOT"]
         self.token = self._get_token()
 
@@ -31,6 +34,9 @@ class Authorization():
         headers['requestUId'] = str(uuid.uuid4())
         headers['accept-language'] = 'EN'
 
+        if getattr(self, "token", None) is not None:
+            headers['authorization'] = "{0} {1}".format("Bearer", self.token)
+
         return headers
 
     def _get_token(self):
